test_covariates_obj: Covariates Object

test_covariates_objR Documentation

Covariates Object

Description

A list containing the frequency and severity relativities for three factors.

Usage

test_covariates_obj

Format

A covariates object with 3 components:

factors

list; levels within each factor.

relativity_freq

data.frame; first and second order frequency relativities between all the levels of each factor

relativity_sev

data.frame; first and second order severity relativities between all the levels of each factor

Examples

test_covariates_obj$factors

SynthETIC documentation built on Aug. 30, 2026, 9:07 a.m.